IT WAS POSTED JUST FOR EDUCATIONAL PURPOSES!

Interface for getting your saved code from AWS S3 straingt into the module - 
like import but for anything non-local
Can be configured with .configure file containing your AWS credentials
or by passing access_key_id and secret_access_id to constructor